@@ -181,6 +181,13 @@
 #' one that fits best given two basis terms.  Change this to, e.g. \code{"iso"},
 #' \code{"aniso"} or \code{"unstr"} if an "Error in eigen..." is obtained.
 #'
+#' For any of the nonparametric regression methods:
+#'
+#' * \code{ref} The reference decision option used to define the
+#'   incremental net benefit, cost or effects before performing
+#'   nonparametric regression.  Either an integer column number, or the
+#'   name of the column from \code{outputs}.
+#'
 ##' For \code{method="so"}:
 ##'
 ##' * \code{n.blocks} Number of blocks to split the sample into. Required.
@@ -281,7 +288,7 @@ evppi <- function(outputs,
     res <- cbind(pars=rep(names(pars), each = nwtp), res)
     if (check){
         attr(res, "models") <- lapply(eres, function(x)attr(x, "models"))
-        names(attr(res, "models")) <- res$pars
+        names(attr(res, "models")) <- names(pars)
     }
     attr(res, "methods") <- methods
     attr(res, "outputs") <- class(outputs)[1]
@@ -310,6 +317,10 @@ subset_outputs.cea <- function(outputs, nsim, ...){
 }
 
 default_evppi_method <- function(pars){
+    default_npreg_method(pars)
+}
+
+default_npreg_method <- function(pars){
     if (length(pars) <= 4) "gam" else "gp"
 }
 
@@ -365,8 +376,7 @@ check_pars <- function(pars, inputs, evppi=TRUE){
             pars <- colnames(inputs)
         else stop("`pars` should be specified if there are two or more parameters in `inputs`")
     }
-    if (!is.null(pars) && !is.character(pars))
-        stop("`pars` should be a character vector")
+    validate_char(pars, "pars")
     badpars <- pars[!(pars %in% colnames(inputs))]
     if (length(badpars)>0){
         stop(sprintf("parameters of interest `%s` not found in columns of `inputs`",
@@ -375,6 +385,12 @@ check_pars <- function(pars, inputs, evppi=TRUE){
     pars
 }
 
+validate_char <- function(x,name=NULL){
+  if (is.null(name)) name <- deparse(substitute(x))
+  if (!is.null(x) && !is.character(x))
+    stop(sprintf("`%s` should be a character vector",name))
+}
+
 clean_pars <- function(pars) {
     parsc <- gsub(" ", "_", pars)
     r_specials <- c("letters","month.abb","month.name","pi")
